package EA;
use Moo;
with( 'MooX::Log::Any');
1;
package Main;
use Test::More ; 
use Log::Any::Test;
use Log::Any qw($log);
my $app=EA->new;
$app->log->error('good log message');
$log->contains_ok(qr/good log message/,"good message was logged");
my $logger=$app->logger('bob');
$logger->info('test');
my $msgs=$logger->msgs;
is_deeply($msgs,[{category=>'bob',message=>'test',level=>'info'}],'test category');
done_testing();
